@@ -6,11 +6,7 @@ setMethod(
             if (missing(t0))
               t0 <- object@t0
             x <- try(
-                     apply(
-                           as.matrix(params),
-                           2,
-                           function(p).Call(do_init_state,object,p,t0)
-                           ),
+                     .Call(do_init_state,object,as.matrix(params),t0),
                      silent=FALSE
                      )
             if (inherits(x,'try-error'))
