@@ -12,20 +12,30 @@ SEXP do_dprocess (SEXP object, SEXP x, SEXP times, SEXP params, SEXP log)
   SEXP X, fn, fcall, rho;
   SEXP dimP, dimX, dimF;
   ntimes = length(times);
-  if (ntimes < 2)
+  if (ntimes < 2) {
+    UNPROTECT(nprotect);
     error("dprocess error: no transitions, no work to do");
+  }
   PROTECT(dimX = GET_DIM(x)); nprotect++;
-  if ((isNull(dimX)) || (length(dimX)!=3))
+  if ((isNull(dimX)) || (length(dimX)!=3)) {
+    UNPROTECT(nprotect);
     error("dprocess error: 'x' must be a rank-3 array");
+  }
   PROTECT(dimP = GET_DIM(params)); nprotect++;
-  if ((isNull(dimP)) || (length(dimP)!=2))
+  if ((isNull(dimP)) || (length(dimP)!=2)) {
+    UNPROTECT(nprotect);
     error("dprocess error: 'params' must be a rank-2 array");
+  }
   xdim = INTEGER(dimX);
   nvars = xdim[0]; nreps = xdim[1];
-  if (nreps != INTEGER(dimP)[1])
+  if (nreps != INTEGER(dimP)[1]) {
+    UNPROTECT(nprotect);
     error("dprocess error: number of columns of 'params' and 'x' do not agree");
-  if (ntimes != INTEGER(dimX)[2])
+  }
+  if (ntimes != INTEGER(dimX)[2]) {
+    UNPROTECT(nprotect);
     error("rprocess error: length of 'times' and 3rd dimension of 'x' do not agree");
+  }
   // extract the process function
   PROTECT(fn = GET_SLOT(object,install("dprocess"))); nprotect++;
   // construct the call
@@ -54,11 +64,15 @@ SEXP do_dprocess (SEXP object, SEXP x, SEXP times, SEXP params, SEXP log)
   PROTECT(rho = (CLOENV(fn))); nprotect++; // environment of the function
   PROTECT(X = eval(fcall,rho)); nprotect++; // do the call
   PROTECT(dimF = GET_DIM(X)); nprotect++;
-  if ((isNull(dimF)) || (length(dimF) != 2))
+  if ((isNull(dimF)) || (length(dimF) != 2)) {
+    UNPROTECT(nprotect);
     error("dprocess error: user 'dprocess' must return a rank-2 array");
+  }
   xdim = INTEGER(dimF);
-  if ((xdim[0] != nreps) || (xdim[1] != ntimes-1))
+  if ((xdim[0] != nreps) || (xdim[1] != ntimes-1)) {
+    UNPROTECT(nprotect);
     error("dprocess error: user 'dprocess' must return a %d x %d array",nreps,ntimes-1);
+  }
   UNPROTECT(nprotect);
   return X;
 }
